# -*- coding: utf-8 -*-
# generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quality_test.proto
"""generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import shared_types_pb2 as shared__types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='quality_test.proto',
  package='prosuite.Microservices.Definitions.QA.Test',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12quality_test.proto\x12*prosuite.Microservices.Definitions.QA.Test\x1a\x12shared_types.proto\"\xa5\x02\n\x12\x45xecuteTestRequest\x12K\n\nworkspaces\x18\x01 \x03(\x0b\x32\x37.prosuite.Microservices.Definitions.Shared.WorkspaceMsg\x12S\n\x0finvolved_tables\x18\x02 \x03(\x0b\x32:.prosuite.Microservices.Definitions.QA.Test.TestDatasetMsg\x12\x46\n\tperimeter\x18\x03 \x01(\x0b\x32\x33.prosuite.Microservices.Definitions.Shared.ShapeMsg\x12\x11\n\ttest_name\x18\x04 \x01(\t\x12\x12\n\nparameters\x18\x05 \x03(\t\"\xcf\x01\n\x13\x45xecuteTestResponse\x12\x1b\n\x13service_call_status\x18\x01 \x01(\x05\x12M\n\x08progress\x18\x02 \x01(\x0b\x32;.prosuite.Microservices.Definitions.QA.Test.TestProgressMsg\x12L\n\x06issues\x18\x03 \x03(\x0b\x32<.prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg\"\x80\x01\n\x0eTestDatasetMsg\x12S\n\x10\x63lass_definition\x18\x01 \x01(\x0b\x32\x39.prosuite.Microservices.Definitions.Shared.ObjectClassMsg\x12\x19\n\x11\x66ilter_expression\x18\x02 \x01(\t\"_\n\x0fTestProgressMsg\x12\x1c\n\x14progress_total_steps\x18\x01 \x01(\x05\x12\x1d\n\x15progress_current_step\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xdb\x02\n\x10\x44\x65tectedIssueMsg\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12K\n\x0eissue_geometry\x18\x02 \x01(\x0b\x32\x33.prosuite.Microservices.Definitions.Shared.ShapeMsg\x12\x15\n\rissue_code_id\x18\x03 \x01(\t\x12\x1e\n\x16issue_code_description\x18\x04 \x01(\t\x12X\n\x10involved_objects\x18\x05 \x03(\x0b\x32>.prosuite.Microservices.Definitions.QA.Test.InvolvedObjectsMsg\x12\x16\n\x0estop_condition\x18\x06 \x01(\x08\x12\x1a\n\x12\x61\x66\x66\x65\x63ted_component\x18\x07 \x01(\t\x12 \n\x18\x63reation_date_time_ticks\x18\x08 \x01(\x03\"t\n\x12InvolvedObjectsMsg\x12J\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x39.prosuite.Microservices.Definitions.Shared.ObjectClassMsg\x12\x12\n\nobject_ids\x18\x02 \x03(\x05\x32\xa2\x01\n\x0fQualityTestGrpc\x12\x8e\x01\n\x07\x45xecute\x12>.prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest\x1a?.prosuite.Microservices.Definitions.QA.Test.ExecuteTestResponse\"\x00\x30\x01\x62\x06proto3'
  ,
  dependencies=[shared__types__pb2.DESCRIPTOR,])




_EXECUTETESTREQUEST = _descriptor.Descriptor(
  name='ExecuteTestRequest',
  full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaces', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest.workspaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='involved_tables', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest.involved_tables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perimeter', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest.perimeter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_name', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest.test_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest.parameters', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=380,
)


_EXECUTETESTRESPONSE = _descriptor.Descriptor(
  name='ExecuteTestResponse',
  full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_call_status', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestResponse.service_call_status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestResponse.progress', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='prosuite.Microservices.Definitions.QA.Test.ExecuteTestResponse.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=590,
)


_TESTDATASETMSG = _descriptor.Descriptor(
  name='TestDatasetMsg',
  full_name='prosuite.Microservices.Definitions.QA.Test.TestDatasetMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_definition', full_name='prosuite.Microservices.Definitions.QA.Test.TestDatasetMsg.class_definition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='prosuite.Microservices.Definitions.QA.Test.TestDatasetMsg.filter_expression', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=721,
)


_TESTPROGRESSMSG = _descriptor.Descriptor(
  name='TestProgressMsg',
  full_name='prosuite.Microservices.Definitions.QA.Test.TestProgressMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress_total_steps', full_name='prosuite.Microservices.Definitions.QA.Test.TestProgressMsg.progress_total_steps', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress_current_step', full_name='prosuite.Microservices.Definitions.QA.Test.TestProgressMsg.progress_current_step', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='prosuite.Microservices.Definitions.QA.Test.TestProgressMsg.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=818,
)


_DETECTEDISSUEMSG = _descriptor.Descriptor(
  name='DetectedIssueMsg',
  full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue_geometry', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.issue_geometry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue_code_id', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.issue_code_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue_code_description', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.issue_code_description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='involved_objects', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.involved_objects', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_condition', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.stop_condition', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_component', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.affected_component', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_date_time_ticks', full_name='prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg.creation_date_time_ticks', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=1168,
)


_INVOLVEDOBJECTSMSG = _descriptor.Descriptor(
  name='InvolvedObjectsMsg',
  full_name='prosuite.Microservices.Definitions.QA.Test.InvolvedObjectsMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='prosuite.Microservices.Definitions.QA.Test.InvolvedObjectsMsg.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_ids', full_name='prosuite.Microservices.Definitions.QA.Test.InvolvedObjectsMsg.object_ids', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1286,
)

_EXECUTETESTREQUEST.fields_by_name['workspaces'].message_type = shared__types__pb2._WORKSPACEMSG
_EXECUTETESTREQUEST.fields_by_name['involved_tables'].message_type = _TESTDATASETMSG
_EXECUTETESTREQUEST.fields_by_name['perimeter'].message_type = shared__types__pb2._SHAPEMSG
_EXECUTETESTRESPONSE.fields_by_name['progress'].message_type = _TESTPROGRESSMSG
_EXECUTETESTRESPONSE.fields_by_name['issues'].message_type = _DETECTEDISSUEMSG
_TESTDATASETMSG.fields_by_name['class_definition'].message_type = shared__types__pb2._OBJECTCLASSMSG
_DETECTEDISSUEMSG.fields_by_name['issue_geometry'].message_type = shared__types__pb2._SHAPEMSG
_DETECTEDISSUEMSG.fields_by_name['involved_objects'].message_type = _INVOLVEDOBJECTSMSG
_INVOLVEDOBJECTSMSG.fields_by_name['dataset'].message_type = shared__types__pb2._OBJECTCLASSMSG
DESCRIPTOR.message_types_by_name['ExecuteTestRequest'] = _EXECUTETESTREQUEST
DESCRIPTOR.message_types_by_name['ExecuteTestResponse'] = _EXECUTETESTRESPONSE
DESCRIPTOR.message_types_by_name['TestDatasetMsg'] = _TESTDATASETMSG
DESCRIPTOR.message_types_by_name['TestProgressMsg'] = _TESTPROGRESSMSG
DESCRIPTOR.message_types_by_name['DetectedIssueMsg'] = _DETECTEDISSUEMSG
DESCRIPTOR.message_types_by_name['InvolvedObjectsMsg'] = _INVOLVEDOBJECTSMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExecuteTestRequest = _reflection.GeneratedProtocolMessageType('ExecuteTestRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTETESTREQUEST,
  '__module__' : 'quality_test_pb2'
  # @@protoc_insertion_point(class_scope:prosuite.Microservices.Definitions.QA.Test.ExecuteTestRequest)
  })
_sym_db.RegisterMessage(ExecuteTestRequest)

ExecuteTestResponse = _reflection.GeneratedProtocolMessageType('ExecuteTestResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTETESTRESPONSE,
  '__module__' : 'quality_test_pb2'
  # @@protoc_insertion_point(class_scope:prosuite.Microservices.Definitions.QA.Test.ExecuteTestResponse)
  })
_sym_db.RegisterMessage(ExecuteTestResponse)

TestDatasetMsg = _reflection.GeneratedProtocolMessageType('TestDatasetMsg', (_message.Message,), {
  'DESCRIPTOR' : _TESTDATASETMSG,
  '__module__' : 'quality_test_pb2'
  # @@protoc_insertion_point(class_scope:prosuite.Microservices.Definitions.QA.Test.TestDatasetMsg)
  })
_sym_db.RegisterMessage(TestDatasetMsg)

TestProgressMsg = _reflection.GeneratedProtocolMessageType('TestProgressMsg', (_message.Message,), {
  'DESCRIPTOR' : _TESTPROGRESSMSG,
  '__module__' : 'quality_test_pb2'
  # @@protoc_insertion_point(class_scope:prosuite.Microservices.Definitions.QA.Test.TestProgressMsg)
  })
_sym_db.RegisterMessage(TestProgressMsg)

DetectedIssueMsg = _reflection.GeneratedProtocolMessageType('DetectedIssueMsg', (_message.Message,), {
  'DESCRIPTOR' : _DETECTEDISSUEMSG,
  '__module__' : 'quality_test_pb2'
  # @@protoc_insertion_point(class_scope:prosuite.Microservices.Definitions.QA.Test.DetectedIssueMsg)
  })
_sym_db.RegisterMessage(DetectedIssueMsg)

InvolvedObjectsMsg = _reflection.GeneratedProtocolMessageType('InvolvedObjectsMsg', (_message.Message,), {
  'DESCRIPTOR' : _INVOLVEDOBJECTSMSG,
  '__module__' : 'quality_test_pb2'
  # @@protoc_insertion_point(class_scope:prosuite.Microservices.Definitions.QA.Test.InvolvedObjectsMsg)
  })
_sym_db.RegisterMessage(InvolvedObjectsMsg)



_QUALITYTESTGRPC = _descriptor.ServiceDescriptor(
  name='QualityTestGrpc',
  full_name='prosuite.Microservices.Definitions.QA.Test.QualityTestGrpc',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1289,
  serialized_end=1451,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='prosuite.Microservices.Definitions.QA.Test.QualityTestGrpc.Execute',
    index=0,
    containing_service=None,
    input_type=_EXECUTETESTREQUEST,
    output_type=_EXECUTETESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUALITYTESTGRPC)

DESCRIPTOR.services_by_name['QualityTestGrpc'] = _QUALITYTESTGRPC

# @@protoc_insertion_point(module_scope)
