# generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import quality_test_pb2 as quality__test__pb2


class QualityTestGrpcStub(object):
    """*
    The quality test definition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Execute = channel.unary_stream(
                '/prosuite.Microservices.Definitions.QA.Test.QualityTestGrpc/Execute',
                request_serializer=quality__test__pb2.ExecuteTestRequest.SerializeToString,
                response_deserializer=quality__test__pb2.ExecuteTestResponse.FromString,
                )


class QualityTestGrpcServicer(object):
    """*
    The quality test definition.
    """

    def Execute(self, request, context):
        """*
        The quality verification RPC.

        *
        Verifies the quality definied in the data dictionary.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QualityTestGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Execute': grpc.unary_stream_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=quality__test__pb2.ExecuteTestRequest.FromString,
                    response_serializer=quality__test__pb2.ExecuteTestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prosuite.Microservices.Definitions.QA.Test.QualityTestGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class QualityTestGrpc(object):
    """*
    The quality test definition.
    """

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/prosuite.Microservices.Definitions.QA.Test.QualityTestGrpc/Execute',
            quality__test__pb2.ExecuteTestRequest.SerializeToString,
            quality__test__pb2.ExecuteTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
